This file is responsible to deal with import of modules and define functions, enums or structs that can be used for all platforms supported. Maybe i should not do this that way because sometimes i need to define everything as public and it might be bad? I dont know if i care though, dont seem to have any downsides.
Modules
- args
- backend
- This file is responsible to make it easier change between using an API or a SQLite as database storage.
- keylogger
- lock
- logger
- platform